#!perl

use Test::More;

plan skip_all => 'Set TEST_POD to enable pod tests' unless $ENV{TEST_POD};

eval "use Test::Pod 1.14";
plan skip_all => "Test::Pod 1.14 required for testing POD" if $@;

all_pod_files_ok();
